"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_plugins_1 = require("@expo/config-plugins");
const withSSLPinning = (config, props) => {
    config = (0, config_plugins_1.withInfoPlist)(config, (config) => {
        const infoPlist = config.modResults;
        // Clean up old TrustKit configuration if it exists
        delete infoPlist.TSKConfiguration;
        infoPlist.NSAppTransportSecurity ?? (infoPlist.NSAppTransportSecurity = {});
        const pinnedDomainsConfig = Object.fromEntries(Object.entries(props ?? {}).map(([hostName, certificates]) => {
            const hasSubdomainsWildcard = hostName.startsWith("*.");
            const hostnameWithoutWildcard = hasSubdomainsWildcard
                ? hostName.slice(2)
                : hostName;
            // Create the pinned leaf identities array from the certificates
            const pinnedLeafIdentities = certificates.map((certificate) => ({
                "SPKI-SHA256-BASE64": certificate,
            }));
            const config = {
                NSIncludesSubdomains: hasSubdomainsWildcard,
                NSPinnedLeafIdentities: pinnedLeafIdentities,
            };
            return [hostnameWithoutWildcard, config];
        }));
        infoPlist.NSAppTransportSecurity.NSPinnedDomains = pinnedDomainsConfig;
        return config;
    });
    config = (0, config_plugins_1.withGradleProperties)(config, (config) => {
        const gradleProperties = config.modResults;
        const existingIndex = gradleProperties.findIndex((prop) => prop.type === "property" && prop.key === "RNAS_PINNING_CONFIG");
        if (existingIndex !== -1) {
            gradleProperties.splice(existingIndex, 1);
        }
        if (!props) {
            return config;
        }
        const domainsConfig = {};
        for (const [hostName, certificates] of Object.entries(props)) {
            const hasSubdomainsWildcard = hostName.startsWith("*.");
            domainsConfig[hostName] = certificates;
            // When passed "*.domain.com", OkHttp will pin all subdomains, but not the root domain
            // To align behaviour between platforms, add pinning of the root domain as well
            if (hasSubdomainsWildcard) {
                domainsConfig[hostName.slice(2)] = certificates;
            }
        }
        gradleProperties.push({
            type: "property",
            key: "RNAS_PINNING_CONFIG",
            value: JSON.stringify(domainsConfig).replaceAll('"', '\\\\"'),
        });
        return config;
    });
    return config;
};
exports.default = withSSLPinning;
